@@ -16,12 +16,16 @@
 
 from .authenticator import Authenticator
 
+
 class NoAuthAuthenticator(Authenticator):
     """Performs no authentication."""
-    authentication_type = 'noAuth'
 
-    def validate(self):
+    def authentication_type(self) -> str:
+        """Returns this authenticator's type ('noauth')."""
+        return Authenticator.AUTHTYPE_NOAUTH
+
+    def validate(self) -> None:
         pass
 
-    def authenticate(self, req):
+    def authenticate(self, req) -> None:
         pass
