@@ -1,5 +1,5 @@
 # coding=utf-8
-# pylint: disable=missing-docstring,protected-access,too-few-public-methods
+# pylint: disable=missing-docstring,protected-access,too-few-public-methods,too-many-lines
 import gzip
 import json
 import os
@@ -357,6 +357,7 @@ def test_request_server_error():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 500
+    assert err.value.status_code == 500
     assert err.value.http_response.headers['Content-Type'] == 'application/json'
     assert err.value.message == 'internal server error'
 
@@ -399,6 +400,7 @@ def test_request_success_invalid_json():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 200
+    assert err.value.status_code == 200
     assert err.value.http_response.headers['Content-Type'] == 'application/json; charset=utf8'
     assert isinstance(err.value.__cause__, requests.exceptions.JSONDecodeError)
     assert "Expecting ':' delimiter: line 1" in str(err.value.__cause__)
@@ -453,6 +455,7 @@ def test_request_fail_401_nonerror_json():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 401
+    assert err.value.status_code == 401
     assert err.value.http_response.headers['Content-Type'] == 'application/json'
     assert err.value.message == error_msg
 
@@ -473,6 +476,7 @@ def test_request_fail_401_error_json():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 401
+    assert err.value.status_code == 401
     assert err.value.http_response.headers['Content-Type'] == 'application/json'
     assert err.value.message == error_msg
 
@@ -492,6 +496,7 @@ def test_request_fail_401_nonjson():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 401
+    assert err.value.status_code == 401
     assert err.value.http_response.headers['Content-Type'] == 'text/plain'
     assert err.value.message == response_body
 
@@ -514,6 +519,7 @@ def test_request_fail_401_badjson():
         prepped = service.prepare_request('GET', url='')
         service.send(prepped)
     assert err.value.code == 401
+    assert err.value.status_code == 401
     assert err.value.http_response.headers['Content-Type'] == 'application/json'
     assert err.value.message == response_body
 
@@ -647,6 +653,66 @@ def test_gzip_compression():
     assert prepped['headers'].get('content-encoding') == 'gzip'
 
 
+def test_gzip_compression_file_input():
+    service = AnyServiceV1('2018-11-20', authenticator=NoAuthAuthenticator())
+    service.set_enable_gzip_compression(True)
+
+    # Should return file-like object with the compressed data when compression is on
+    # and the input is a file, opened for reading in binary mode.
+    raw_data = b'rawdata'
+    with tempfile.TemporaryFile(mode='w+b') as tmp_file:
+        tmp_file.write(raw_data)
+        tmp_file.seek(0)
+
+        prepped = service.prepare_request('GET', url='', data=tmp_file)
+        assert prepped['data'].read() == gzip.compress(raw_data)
+        assert prepped['headers'].get('content-encoding') == 'gzip'
+        assert prepped['data'].read() == b''
+
+    # Simulate the requests (urllib3) package reading method for binary files.
+    with tempfile.TemporaryFile(mode='w+b') as tmp_file:
+        tmp_file.write(raw_data)
+        tmp_file.seek(0)
+
+        prepped = service.prepare_request('GET', url='', data=tmp_file)
+        compressed = b''
+        for chunk in prepped['data']:
+            compressed += chunk
+
+        assert compressed == gzip.compress(raw_data)
+
+    # Make sure the decompression works fine.
+    assert gzip.decompress(compressed) == raw_data
+
+    # Should return file-like object with the compressed data when compression is on
+    # and the input is a file, opened for reading in text mode.
+    assert service.get_enable_gzip_compression()
+    text_data = 'textdata'
+    with tempfile.TemporaryFile(mode='w+') as tmp_file:
+        tmp_file.write(text_data)
+        tmp_file.seek(0)
+
+        prepped = service.prepare_request('GET', url='', data=tmp_file)
+        assert prepped['data'].read() == gzip.compress(text_data.encode())
+        assert prepped['headers'].get('content-encoding') == 'gzip'
+        assert prepped['data'].read() == b''
+
+    # Simulate the requests (urllib3) package reading method for text files.
+    with tempfile.TemporaryFile(mode='w+') as tmp_file:
+        tmp_file.write(text_data)
+        tmp_file.seek(0)
+
+        prepped = service.prepare_request('GET', url='', data=tmp_file)
+        compressed = b''
+        for chunk in prepped['data']:
+            compressed += chunk
+
+        assert compressed == gzip.compress(text_data.encode())
+
+    # Make sure the decompression works fine.
+    assert gzip.decompress(compressed).decode() == text_data
+
+
 def test_gzip_compression_external():
     # Should set gzip compression from external config
     file_path = os.path.join(os.path.dirname(__file__), '../resources/ibm-credentials-gzip.env')
@@ -664,6 +730,7 @@ def test_retry_config_default():
     service.enable_retries()
     assert service.retry_config.total == 4
     assert service.retry_config.backoff_factor == 1.0
+    assert service.retry_config.backoff_max == 30.0
     assert service.http_client.get_adapter('https://').max_retries.total == 4
 
     # Ensure retries fail after 4 retries
@@ -696,9 +763,10 @@ def test_retry_config_disable():
 
 def test_retry_config_non_default():
     service = BaseService(service_url='https://mockurl/', authenticator=NoAuthAuthenticator())
-    service.enable_retries(2, 0.3)
+    service.enable_retries(2, 10.0)
     assert service.retry_config.total == 2
-    assert service.retry_config.backoff_factor == 0.3
+    assert service.retry_config.backoff_factor == 1.0
+    assert service.retry_config.backoff_max == 10.0
 
     # Ensure retries fail after 2 retries
     error = ConnectTimeoutError()
@@ -715,7 +783,8 @@ def test_retry_config_external():
     os.environ['IBM_CREDENTIALS_FILE'] = file_path
     service = IncludeExternalConfigService('v1', authenticator=NoAuthAuthenticator())
     assert service.retry_config.total == 3
-    assert service.retry_config.backoff_factor == 0.2
+    assert service.retry_config.backoff_factor == 1.0
+    assert service.retry_config.backoff_max == 25.0
 
     # Ensure retries fail after 3 retries
     error = ConnectTimeoutError()
